@@ -12,7 +12,7 @@ Usage::
     session_client: SSOOIDCClient = session.client("sso-oidc")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_sso_oidc.type_defs import (
     CreateTokenResponseTypeDef,
@@ -25,19 +25,19 @@ __all__ = ("SSOOIDCClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Boto3ClientError
-    AuthorizationPendingException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ExpiredTokenException: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    InvalidClientException: Boto3ClientError
-    InvalidClientMetadataException: Boto3ClientError
-    InvalidGrantException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    InvalidScopeException: Boto3ClientError
-    SlowDownException: Boto3ClientError
-    UnauthorizedClientException: Boto3ClientError
-    UnsupportedGrantTypeException: Boto3ClientError
+    AccessDeniedException: Type[Boto3ClientError]
+    AuthorizationPendingException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ExpiredTokenException: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    InvalidClientException: Type[Boto3ClientError]
+    InvalidClientMetadataException: Type[Boto3ClientError]
+    InvalidGrantException: Type[Boto3ClientError]
+    InvalidRequestException: Type[Boto3ClientError]
+    InvalidScopeException: Type[Boto3ClientError]
+    SlowDownException: Type[Boto3ClientError]
+    UnauthorizedClientException: Type[Boto3ClientError]
+    UnsupportedGrantTypeException: Type[Boto3ClientError]
 
 
 class SSOOIDCClient:
